
/*
 * This first section contains constants which can be changed at will.
 */

/* Default initial maximum records to sort */
#define DEFMAXRECORDS	10240

/* Initial size of input text buffer */
#define INPUTTEXTSIZEINIT 8192

/* Initial maximum fields in a record */
#define DEFMAXFIELDS 32

/* Maximum length of numeric string */
#define MAXDOUBLELEN 256


/* The following can't be changed freely since they reflect the Unicode standard */
#define MAXUNICODE 0x1FFFFF
#define MAXBMP     0x00FFFF

#define NPU_FIRSTMULTIGRAPHCODE 0xD800
#define NPU_MAXMULTIGRAPHCODE 0xDFFF
#define NPU_MAXMULTIGRAPHS (NPU_MAXMULTIGRAPHCODE - NPU_FIRSTMULTIGRAPHCODE + 1)

#define BMP_FIRSTMULTIGRAPHCODE 0xE000
#define BMP_MAXMULTIGRAPHCODE 0xF8FF
#define BMP_MAXMULTIGRAPHS (BMP_MAXMULTIGRAPHCODE - BMP_FIRSTMULTIGRAPHCODE + 1)

#define FUL_FIRSTMULTIGRAPHCODE 0xF0000
#define FUL_MAXMULTIGRAPHCODE 0x10FFFD
#define FUL_MAXMULTIGRAPHS (FUL_MAXMULTIGRAPHCODE - FUL_FIRSTMULTIGRAPHCODE + 1)
